@@ -50,8 +50,8 @@ extern "C" {
 }
 
 #[inline(always)]
-pub unsafe fn PyCode_Check(op : *mut PyObject) -> bool {
+pub unsafe fn PyCode_Check(op : *mut PyObject) -> c_int {
     let u : *mut PyTypeObject = &mut PyCode_Type;
-    Py_TYPE(op) == u
+    (Py_TYPE(op) == u) as c_int
 }
 
